@@ -16,26 +16,31 @@
 from gi.repository import Gio, GLib
 
 
-LOLLYPOP_DATA_PATH = GLib.get_user_data_dir() + "/lollypop"
-
 App = Gio.Application.get_default
 
+LASTFM_API_KEY = "7a9619a850ccf7377c46cf233c51e3c6"
+LASTFM_API_SECRET = "9254319364d73bec6c59ace485a95c98"
+
+DISCOGS_API_KEY = "vcKgyONtKsaQZLvpUfOU"
+DISCOGS_API_SECRET = "SmWphfGWALsmDnoyhPuQlDDQEIvFJuPM"
+
 GOOGLE_API_ID = "015987506728554693370:waw3yqru59a"
 
+MARGIN_BIG = 30
 MARGIN = 15
 MARGIN_MEDIUM = 10
 MARGIN_SMALL = 5
 
-data_dir = GLib.get_user_data_dir()
+LOLLYPOP_DATA_PATH = GLib.get_user_data_dir() + "/lollypop"
 # All cache goes here
 CACHE_PATH = GLib.get_user_cache_dir() + "/lollypop"
 # Stores for albums
-ALBUMS_PATH = data_dir + "/lollypop/albums"
-ALBUMS_WEB_PATH = data_dir + "/lollypop/albums_web"
+ALBUMS_PATH = LOLLYPOP_DATA_PATH + "/albums"
+ALBUMS_WEB_PATH = LOLLYPOP_DATA_PATH + "/albums_web"
 # Stores for artists
-ARTISTS_PATH = data_dir + "/lollypop/artists"
+ARTISTS_PATH = LOLLYPOP_DATA_PATH + "/artists"
 # Store for lyrics
-LYRICS_PATH = data_dir + "/lollypop/lyrics"
+LYRICS_PATH = LOLLYPOP_DATA_PATH + "/lyrics"
 
 
 class TimeStamp:
@@ -44,6 +49,13 @@ class TimeStamp:
     THREE_YEAR = 94608000
 
 
+class FileType:
+    UNKNOWN = 0
+    AUDIO = 1
+    PLS = 2
+    OTHER = 3
+
+
 class Repeat:
     NONE = 0
     AUTO_SIMILAR = 1
@@ -67,7 +79,8 @@ class StorageType:
     SPOTIFY_SIMILARS = 1 << 5
     EXTERNAL = 1 << 6
     SEARCH = 1 << 7
-    ALL = 1 << 1 | 1 << 2 | 1 << 3 | 1 << 4 | 1 << 5 | 1 << 6 | 1 << 7
+    DEEZER_CHARTS = 1 << 8
+    ALL = 1 << 1 | 1 << 2 | 1 << 3 | 1 << 4 | 1 << 5 | 1 << 6 | 1 << 7 | 1 << 8
 
 
 class ArtBehaviour:
@@ -95,7 +108,7 @@ class ViewType:
     PLAYLISTS = 1 << 5
     ALBUM = 1 << 6
     SMALL = 1 << 7
-    ADAPTIVE = 1 << 8
+    # ADAPTIVE = 1 << 8
     SCROLLED = 1 << 9
     OVERLAY = 1 << 10
     FULLSCREEN = 1 << 11
@@ -113,7 +126,7 @@ NetworkAccessACL = {
     "GOOGLE": 1 << 5,
     "STARTPAGE": 1 << 6,
     "WIKIPEDIA": 1 << 7,
-    "TUNEIN": 1 << 8,
+    #    "TUNEIN": 1 << 8,
     "MUSICBRAINZ": 1 << 9,
     "ITUNES": 1 << 10,
     "DEEZER": 1 << 11,
@@ -121,7 +134,10 @@ NetworkAccessACL = {
     "GENIUS": 1 << 13,
     "AUDIODB": 1 << 14,
     "FANARTTV": 1 << 15,
-    "DUCKDUCKGO": 1 << 16
+    "DUCKDUCKGO": 1 << 16,
+    "LIBREFM": 1 << 17,
+    "METROLYRICS": 1 << 18,
+    "BING": 1 << 19
 }
 
 
@@ -165,7 +181,7 @@ class ScanUpdate:
 class SelectionListMask:
     NONE = 1 << 0
     SIDEBAR = 1 << 1
-    VIEW = 1 << 2
+    FASTSCROLL = 1 << 2
     ARTISTS = 1 << 3
     GENRES = 1 << 4
     PLAYLISTS = 1 << 5
@@ -193,32 +209,22 @@ class ReplayGain:
     ALBUM = 1
 
 
-class AdaptiveSize:
-    NONE = 1 << 0
-    PHONE = 1 << 1
-    SMALL = 1 << 2
-    MEDIUM = 1 << 3
-    NORMAL = 1 << 4
-    BIG = 1 << 5
-    LARGE = 1 << 6
-
-
 class Size:
     MINI = 250
     PHONE = 360  # Librem Phone
     SMALL = 500
     MEDIUM = 720
-    NORMAL = 1000
-    BIG = 1300
+    NORMAL = 850
+    BIG = 1000
 
 
 class OrderBy:
-    ARTIST = 0
-    NAME = 1
-    YEAR_DESC = 2
-    POPULARITY = 3
-    YEAR_ASC = 4  # Not available for user
-    GENRE = 5
+    ARTIST_YEAR = 0
+    ARTIST_TITLE = 1
+    TITLE = 2
+    YEAR_DESC = 3
+    POPULARITY = 4
+    YEAR_ASC = 5
 
 
 # Order is important
@@ -241,23 +247,16 @@ class Type:
     GENRES_LIST = -14
     YEARS = -15
     PLAYLISTS = -16
-    RADIOS = -17
-    INFO = -18
     SMART = -19
     EQUALIZER = -20
-    SETTINGS = -21
-    SETTINGS_APPEARANCE = -22
-    SETTINGS_BEHAVIOUR = -23
-    SETTINGS_COLLECTIONS = -24
-    SETTINGS_WEB = -25
-    SETTINGS_DEVICES = -26
     DEVICE_ALBUMS = -27
     DEVICE_PLAYLISTS = -28
     ALBUM = -29
     SEPARATOR = -100
     CURRENT = -101
-    SEARCH = -102
-    LYRICS = -103
+    INFO = -102
+    SEARCH = -103
+    LYRICS = -104
 
 
 LATIN1_ENCODING = b"\x00"
