@@ -81,7 +81,8 @@ def is_pls(info):
     """
     if info is not None:
         if info.get_content_type() in ["audio/x-mpegurl",
-                                       "application/xspf+xml"]:
+                                       "application/xspf+xml",
+                                       "application/vnd.apple.mpegurl"]:
             return True
     return False
 
@@ -91,15 +92,11 @@ def get_mtime(info):
         Return Last modified time of a given file
         @param info as Gio.FileInfo
     """
-    # Using time::changed is not reliable making lollypop doing a full
-    # scan every two weeks (on my computer)
-    # try:
-    #    # We do not use time::modified because many tag editors
-    #    # just preserve this setting
-    #    return int(info.get_attribute_as_string("time::changed"))
-    # except:
-    #    pass
-    return int(info.get_attribute_as_string("time::modified"))
+    mtime = info.get_attribute_as_string("time::modified")
+    if mtime is None:
+        return 0
+    else:
+        return int(mtime)
 
 
 def remove_oldest(path, timestamp):
@@ -200,32 +197,22 @@ def id3EncodingToString(encoding):
         raise ValueError("Encoding unknown: %s" % encoding)
 
 
+# From eyeD3 start
 def decodeUnicode(bites, encoding):
     codec = id3EncodingToString(encoding)
-    Logger.debug("Unicode encoding: %s" % codec)
-    if (codec.startswith("utf_16") and
-            len(bites) % 2 != 0 and bites[-1:] == b"\x00"):
-        # Catch and fix bad utf16 data, it is everywhere.
-        Logger.warning("Fixing utf16 data with extra zero bytes")
-        bites = bites[:-1]
-    return bites.decode(codec).rstrip("\x00")
+    return bites.decode(codec)
 
 
 def splitUnicode(data, encoding):
-    from lollypop.define import LATIN1_ENCODING, UTF_8_ENCODING
     from lollypop.define import UTF_16_ENCODING, UTF_16BE_ENCODING
     try:
-        if encoding == LATIN1_ENCODING or encoding == UTF_8_ENCODING:
-            (d, t) = data.split(b"\x00", 1)
-        elif encoding == UTF_16_ENCODING or encoding == UTF_16BE_ENCODING:
-            # Two null bytes split, but since each utf16 char is also two
-            # bytes we need to ensure we found a proper boundary.
-            (d, t) = data.split(b"\x00\x00", 1)
-            if (len(d) % 2) != 0:
-                (d, t) = data.split(b"\x00\x00\x00", 1)
-                d += b"\x00"
-    except ValueError as ex:
-        Logger.warning("Invalid 2-tuple ID3 frame data: %s", ex)
-        d, t = data, b""
+        (d, t) = data.split(encoding, 1)
+        # Fix invalid UTF16
+        if encoding == UTF_16_ENCODING or encoding == UTF_16BE_ENCODING:
+            if len(t) % 2 != 0:
+                t = t[1:]
+    except ValueError as e:
+        Logger.warning("splitUnicode(): %s", e)
+        (d, t) = data, b""
     return (d, t)
 # From eyeD3 end
