@@ -18,7 +18,7 @@ from lollypop.widgets_row_track import TrackRow
 from lollypop.objects_album import Album
 from lollypop.logger import Logger
 from lollypop.utils import set_cursor_type, emit_signal
-from lollypop.define import App, Type, ViewType
+from lollypop.define import App, ViewType
 from lollypop.view_tracks import TracksView
 
 
@@ -64,11 +64,7 @@ class AlbumTracksView(TracksView):
             self.__populated = True
             emit_signal(self, "populated")
             if not self.children:
-                text = (_("""This album has no track."""
-                          """ Check tags, all 'album artist'"""
-                          """ tags should be in 'artist' tags"""))
-                label = Gtk.Label.new(text)
-                label.get_style_context().add_class("text-large")
+                label = Gtk.Label.new(_("All tracks skipped"))
                 label.show()
                 self._responsive_widget.insert_row(0)
                 self._responsive_widget.attach(label, 0, 0, 2, 1)
@@ -81,6 +77,8 @@ class AlbumTracksView(TracksView):
             @param position as int
         """
         self._init()
+        if not self.is_populated:
+            self.populate()
         self.__album.append_track(track)
         for key in self._tracks_widget_left.keys():
             self._add_tracks(self._tracks_widget_left[key], [track])
@@ -93,11 +91,23 @@ class AlbumTracksView(TracksView):
             @param tracks as [Track]
         """
         self._init()
+        if not self.is_populated:
+            self.populate()
         self.__album.append_tracks(tracks)
         for key in self._tracks_widget_left.keys():
             self._add_tracks(self._tracks_widget_left[key], tracks)
             return
 
+    def remove_row(self, track):
+        """
+            Remove row for track
+            @param track as Track
+        """
+        self.__album.remove_track(track)
+        for child in self.children:
+            if child.track == track:
+                child.destroy()
+
     def set_playing_indicator(self):
         """
             Set playing indicator
@@ -193,10 +203,9 @@ class AlbumTracksView(TracksView):
             # If user does not want to show real tracknumber and we are
             # in album view, calculate a fake tracknumber
             if not self.__show_tag_tracknumber and\
-                    self.view_type & ViewType.ALBUM:
+                    self.view_type & (ViewType.ALBUM | ViewType.ARTIST):
                 track.set_number(position + 1)
-            row = TrackRow(track, self.__album.artist_ids, self.view_type,
-                           self.__show_tag_tracknumber)
+            row = TrackRow(track, self.__album.artist_ids, self.view_type)
             row.show()
             row.connect("removed", self.__on_track_row_removed)
             widget.add(row)
@@ -280,29 +289,6 @@ class AlbumTracksView(TracksView):
         if self.__album.is_web:
             TracksView._on_loading_changed(self, player, status, track)
 
-    def _on_album_updated(self, scanner, album_id):
-        """
-            On album modified, disable it
-            @param scanner as CollectionScanner
-            @param album_id as int
-        """
-        if self.__album.id != album_id:
-            return
-        removed = False
-        for dic in [self._tracks_widget_left, self._tracks_widget_right]:
-            for widget in dic.values():
-                for child in widget.get_children():
-                    if child.track.album.id == Type.NONE:
-                        removed = True
-        if removed:
-            for dic in [self._tracks_widget_left, self._tracks_widget_right]:
-                for widget in dic.values():
-                    for child in widget.get_children():
-                        child.destroy()
-            self.__discs = list(self.__discs)
-            self.__set_duration()
-            self.populate()
-
     def __on_track_row_removed(self, row):
         """
             Pass signal
@@ -316,15 +302,17 @@ class AlbumTracksView(TracksView):
             @param widget as TracksWidget
             @param track as Track
         """
-        if self.view_type & ViewType.ALBUM:
+        if self.view_type & (ViewType.ALBUM | ViewType.ARTIST):
             tracks = []
             for child in self.children:
-                if child.track.loved != -1:
+                if child.track.loved != -1 or track.id == child.track.id:
                     tracks.append(child.track)
                 child.set_state_flags(Gtk.StateFlags.NORMAL, True)
             # Do not update album list if in party or album already available
-            if not App().player.is_party and\
-                    not App().player.track_in_playback(track):
+            playback_track = App().player.track_in_playback(track)
+            if playback_track is not None:
+                App().player.load(playback_track)
+            elif not App().player.is_party:
                 album = Album(track.album.id, [], [])
                 album.set_tracks(tracks)
                 if not App().settings.get_value("append-albums"):
